package cn.teammodel.controller.frontend;

import cn.teammodel.common.R;
import cn.teammodel.model.dto.weekDuty.DeleteDutyNodeDto;
import cn.teammodel.model.dto.weekDuty.DutyVoteDto;
import cn.teammodel.model.dto.weekDuty.InsertDutyNodeDto;
import cn.teammodel.model.dto.weekDuty.UpdateDutyNodeDto;
import cn.teammodel.model.entity.weekDuty.WeekDuty;
import cn.teammodel.service.DutyService;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;

/**
 * @author winter
 * @create 2024-01-03 10:06
 */
@RestController
@RequestMapping("/duty")
public class DutyController {
    @Resource
    private DutyService dutyService;

    @GetMapping("/getTree")
    @ApiOperation("获取值周评价标准树(不存在则拷贝模板)")
    public R<WeekDuty> getTree() {
        WeekDuty weekDuty = dutyService.getTree();
        return R.success(weekDuty);
    }

    @PostMapping("/insertNode")
    @ApiOperation("插入值周评价标准树节点")
    public R<WeekDuty> insertNode(@RequestBody @Valid InsertDutyNodeDto insertDutyNodeDto) {
        WeekDuty weekDuty = dutyService.insertNode(insertDutyNodeDto);
        return R.success(weekDuty);
    }

    @PostMapping("/deleteNode")
    @ApiOperation("删除值周评价标准树节点")
    public R<WeekDuty> deleteNode(@RequestBody @Valid DeleteDutyNodeDto deleteDutyNodeDto) {
        WeekDuty weekDuty = dutyService.deleteNode(deleteDutyNodeDto);
        return R.success(weekDuty);
    }

    @PostMapping("/updateNode")
    @ApiOperation("更新值周评价标准树节点")
    public R<WeekDuty> updateNode(@RequestBody @Valid UpdateDutyNodeDto updateDutyNodeDto) {
        WeekDuty weekDuty = dutyService.updateNode(updateDutyNodeDto);
        return R.success(weekDuty);
    }

    @PostMapping("/vote")
    @ApiOperation("值周评价投票")
    public R<String> vote(@RequestBody @Valid DutyVoteDto dutyVoteDto) {
        dutyService.vote(dutyVoteDto);
        return R.success("评价成功");
    }





}
